
.. _whatsnew_103:

What's new in 1.0.3 (March 17, 2020)
------------------------------------

These are the changes in pandas 1.0.3. See :ref:`release` for a full changelog
including other versions of pandas.

{{ header }}

.. ---------------------------------------------------------------------------

.. _whatsnew_103.regressions:

Fixed regressions
~~~~~~~~~~~~~~~~~
- Fixed regression in ``resample.agg`` when the underlying data is non-writeable (:issue:`31710`)
- Fixed regression in :class:`DataFrame` exponentiation with reindexing (:issue:`32685`)

.. _whatsnew_103.bug_fixes:

Bug fixes
~~~~~~~~~

Contributors
~~~~~~~~~~~~

.. contributors:: v1.0.2..v1.0.3
